@@ -1,8 +1,14 @@
 pub mod context;
 pub use context::Context;
+pub mod option;
+pub use option::Option;
 pub mod primitive_i32;
 pub use primitive_i32::PrimitiveI32;
 pub mod primitive_usize;
 pub use primitive_usize::PrimitiveUSize;
+pub mod result;
+pub use result::Result;
 pub mod string;
 pub use string::String;
+pub mod vec;
+pub use vec::Vec;
